@@ -23,12 +23,12 @@ class History(object):
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
             "Accept": "application/json",
-            "User-Agent": "Python API 1.84 / {local_version}".format(local_version=platform.python_version())
+            "User-Agent": "Python API 1.86 / {local_version}".format(local_version=platform.python_version())
         }
 
         self._dataset_id = None
     
-    def _requests(self, method, url, headers={}, data={}, json={}, params={}, stream=False):
+    def _requests(self, method, url, headers={}, data={}, json={}, params={}, stream=False, allow_redirects=True):
         if method not in ['post', 'get']:
             raise Exception('Not allowed method')
         return getattr(requests, method)(
@@ -39,7 +39,8 @@ class History(object):
             params=params,
             stream=stream,
             proxies=self._proxies,
-            verify=self._verify
+            verify=self._verify,
+            allow_redirects=allow_redirects
         )
 
     def _authenticate(self):
@@ -56,6 +57,16 @@ class History(object):
             raise Exception('Invalid autentication')
         self._token = json.loads(response.text)['auth_token']
 
+    def get_dataset_list(self):
+        response = self._requests(
+            method='get',
+            url='{base_url}/datasets/'.format(base_url=self._BASE_URL),
+            headers=self._headers
+        )
+        if response.status_code != self.OK:
+            self._raise_exception_from_response(response)
+        return json.loads(response.text).get('datasets', [])
+
     def get_history_list(self, dataset_id):
         if not dataset_id:
             raise Exception('Invalid dataset_id')
@@ -89,6 +100,31 @@ class History(object):
         )
         return json.loads(response.text)
 
+    def get_presigned_url(self, dataset_id, history_date):
+        if not dataset_id:
+            raise Exception('Invalid dataset_id')
+
+        if not history_date:
+            raise Exception('Invalid history_date')
+
+        response = self._requests(
+            method='get', 
+            url='{base_url}/datasets/{dataset_id}/history/{history_date}'.format(
+                base_url=self._BASE_URL,
+                dataset_id=dataset_id,
+                history_date=history_date
+            ),
+            headers=dict(
+                self._headers,
+                **{
+                    "Accept": "text/csv",
+                    "Accept-Encoding": "gzip"
+                }
+            ),
+            allow_redirects=False
+        )
+        return response.headers['Location']
+
     def download(self, dataset_id, history_date, download_path=None, is_compressed=False):
         if not dataset_id:
             raise Exception('Invalid dataset_id')
